@@ -72,7 +72,7 @@ mpi.scatter.Robj2slave=function (obj, comm = 1) {
         rank = 0, comm = comm)
     mpi.scatter.Robj(obj=c(list("master"),obj), root = 0, comm = comm)
     mpi.bcast.cmd(cmd = assign(.tmpname$objname, .tmpRobj, 
-        env = .GlobalEnv), rank = 0, comm = comm)
+        envir = .GlobalEnv), rank = 0, comm = comm)
 }
 
 mpi.gather.Robj <- function(obj=NULL, root=0, comm=1){
@@ -184,7 +184,7 @@ mpi.bcast.Robj2slave <- function(obj, comm=1){
                     rank=0, comm=comm)
     mpi.bcast.Robj(obj, rank=0, comm=comm)
     mpi.bcast.cmd(cmd=assign(.tmpRobj$objname,.tmpRobj$obj, 
-            env = .GlobalEnv), rank=0, comm=comm)
+            envir = .GlobalEnv), rank=0, comm=comm)
     #mpi.bcast.cmd(rm(.tmpRobj,envir = .GlobalEnv), rank=0, comm=comm) 
 }
 
